<?php

namespace App\Controller;

use App\Entity\Panier;
use App\Entity\Produits;
use App\Repository\ProduitsRepository;
use App\Repository\PanierRepository;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\HttpFoundation\Request;

#[Route('/panier')]
class PanierController extends AbstractController
{
    #[Route('/', name: 'app_panier_index', methods: ['GET'])]
    public function index(PanierRepository $panierRepository): Response
    {
        return $this->render('panier/index.html.twig', [
            'paniers' => $panierRepository->findAll(),
        ]);
    }


    #[Route('/{id}', name: 'app_panier_show', methods: ['GET'])]
    public function show(Panier $panier): Response
    {

        return $this->render('panier/show.html.twig', [
            'panier' => $panier,
        ]);
    }

    #[Route('/{id}/edit', name: 'app_panier_edit', methods: ['GET', 'POST'])]
    public function edit(Request $request, Panier $panier, EntityManagerInterface $entityManager): Response
    {
        $form = $this->createForm(PanierType::class, $panier);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $entityManager->flush();

            return $this->redirectToRoute('app_panier_index', [], Response::HTTP_SEE_OTHER);
        }

        return $this->render('panier/edit.html.twig', [
            'panier' => $panier,
            'form' => $form,
        ]);
    }

    #[Route('/{id}', name: 'app_panier_delete', methods: ['POST'])]
    public function delete(Request $request, Panier $panier, EntityManagerInterface $entityManager): Response
    {
        if ($this->isCsrfTokenValid('delete'.$panier->getId(), $request->request->get('_token'))) {
            $entityManager->remove($panier);
            $entityManager->flush();
        }

        return $this->redirectToRoute('app_panier_index', [], Response::HTTP_SEE_OTHER);
    }

    #[Route('/add-to-cart/{produitId}', name: 'app_panier_add_to_cart', methods: ['GET'])]
    public function addToCart(int $produitId, ProduitsRepository $produitsRepository, EntityManagerInterface $entityManager, PanierRepository $panierRepository): Response
    {
        $user = $this->getUser();
        if (!$user) {
            throw $this->createAccessDeniedException('Vous devez être connecté pour ajouter un produit au panier.');
        }

        $produit = $produitsRepository->find($produitId);
        if (!$produit) {
            throw $this->createNotFoundException('Le produit n\'existe pas.');
        }

        $panier = $user->getPanier();
        if (!$panier) {
            $panier = new Panier();
            $user->setPanier($panier);
            $panier->setDateCreation((new \DateTime())->format('Y-m-d H:i:s'));
            // Pas besoin de définir `client_id` ici, car il est défini par `setPanier` sur l'entité User
        }

        $panier->addProduitId($produit);

        $entityManager->persist($panier);
        $entityManager->flush();

        $this->addFlash('success3', 'Le produit a été ajouté à votre panier.');

        return $this->redirectToRoute('app_panier_show', ['id' => $panier->getId()]);

    }

    #[Route('/{id}/commande', name: 'app_panier_buy', methods: ['GET'])]
    public function buy(Panier $panier, EntityManagerInterface $entityManager): Response
    {
        $allInPanier = $panier->getProduitId();

        foreach ($allInPanier as $produit) {
            // Ici je rajoute combien de fois le prdouti à été commandé et supprime du coup un stock
            $produit->setBuycount($produit->getBuycount() + 1);
            $produit->setStock($produit->getStock() - 1);
            // Sauvegarder les changement dans la base de données
            $entityManager->persist($produit);
            $panier->removeProduitId($produit);
        }

        $entityManager->flush();


        return $this->render('panier/valid.html.twig', [
            'panier' => $panier,
            'o' => $allInPanier
        ]);
    }

    #[Route('/{id}/remove/{produitId}', name: 'remove_from_panier', methods: ['GET'])]
    public function removeProduct(Panier $panier, int $produitId, EntityManagerInterface $entityManager): Response
    {
        // Récupérer le produit à supprimer du panier
        $produit = $entityManager->getRepository(Produits::class)->find($produitId);

        // Supprimer le produit du panier
        $panier->removeProduitId($produit);

        // Enregistrer les modifications dans la base de données
        $entityManager->flush();

        // Rediriger vers la page du panier
        return $this->redirectToRoute('app_panier_show', ['id' => $panier->getId()]);
    }
}
