<?php

namespace App\Controller;

use App\Entity\Sexe;
use App\Form\SexeType;
use App\Repository\SexeRepository;
use App\Entity\Marque;
use App\Entity\Couleur;
use App\Form\CouleurType;
use App\Repository\CouleurRepository;
use App\Form\MarqueType;
use App\Repository\MarqueRepository;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Attribute\Route;

#[Route('/sexe')]
class SexeController extends AbstractController
{
    #[Route('/', name: 'app_sexe_index', methods: ['GET'])]
    public function index(SexeRepository $sexeRepository): Response
    {
        return $this->render('sexe/index.html.twig', [
            'sexes' => $sexeRepository->findAll(),
        ]);
    }

    #[Route('/new', name: 'app_sexe_new', methods: ['GET', 'POST'])]
    public function new(Request $request, EntityManagerInterface $entityManager): Response
    {
        $sexe = new Sexe();
        $form = $this->createForm(SexeType::class, $sexe);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $entityManager->persist($sexe);
            $entityManager->flush();

            return $this->redirectToRoute('app_sexe_index', [], Response::HTTP_SEE_OTHER);
        }

        return $this->render('sexe/new.html.twig', [
            'sexe' => $sexe,
            'form' => $form,
        ]);
    }

    #[Route('/{id}', name: 'app_sexe_show', methods: ['GET'])]
    public function show(Sexe $sexes, Marque $marque,  CouleurRepository $couleurRepository, MarqueRepository $marqueRepository, SexeRepository $sexeRepository): Response
    {
        $couleurs = $couleurRepository->findAll();
        $marques = $marqueRepository->findAll();
        $sexe = $sexeRepository->findAll();

        return $this->render('sexe/show.html.twig', [
            'couleurs'=> $couleurs,
            'marques' => $marques,
            'sexes' => $sexes,
            'sexe' => $sexe,
        ]);
    }

    #[Route('/{id}/edit', name: 'app_sexe_edit', methods: ['GET', 'POST'])]
    public function edit(Request $request, Sexe $sexe, EntityManagerInterface $entityManager): Response
    {
        $form = $this->createForm(SexeType::class, $sexe);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $entityManager->flush();

            return $this->redirectToRoute('app_sexe_index', [], Response::HTTP_SEE_OTHER);
        }

        return $this->render('sexe/edit.html.twig', [
            'sexe' => $sexe,
            'form' => $form,
        ]);
    }

    #[Route('/{id}', name: 'app_sexe_delete', methods: ['POST'])]
    public function delete(Request $request, Sexe $sexe, EntityManagerInterface $entityManager): Response
    {
        if ($this->isCsrfTokenValid('delete'.$sexe->getId(), $request->request->get('_token'))) {
            $entityManager->remove($sexe);
            $entityManager->flush();
        }

        return $this->redirectToRoute('app_sexe_index', [], Response::HTTP_SEE_OTHER);
    }
}
